# awsmate

A companion for your AWS Python developments.

## Testing

* Testing tool: `pytest`
* Command line: `pytest [-v|-vv]`. Should be run from the base directory of the repository.
* Tests files location:

        awsmate
            |___tests
                    |
                    |___unit
                    |
                    |___integration


## License

EUROPEAN UNION PUBLIC LICENCE (EUPL) v. 1.2.

Please see `LICENSE.txt` for details.
